==> haskell-generically-0.1.1-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generically.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 generically
version:              0.1.1
visibility:           public
id:                   generically-0.1.1-CdUVFizDlThDUMblYC8hNp
key:                  generically-0.1.1-CdUVFizDlThDUMblYC8hNp
license:              BSD-3-Clause
copyright:            2022 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus
synopsis:             Generically newtype to use with DerivingVia
description:
    This is a compatibility package as @Generically@ and @Generically1@ newtypes
    are available since @base-4.17@ in '\''GHC.Generics'\''.

category:             Generics
abi:                  76aa1e4ba86e8531f51effe08eaa6397
exposed:              True
exposed-modules:      GHC.Generics.Generically
import-dirs:          /usr/lib/ghc-9.4.8/site-local/generically-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/generically-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/generically-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-generically
hs-libraries:         HSgenerically-0.1.1-CdUVFizDlThDUMblYC8hNp
depends:
    base-4.17.2.1 base-orphans-0.9.1-2rJDju77cxE7neoO2s5xxe

haddock-interfaces:   /usr/share/doc/haskell-generically/html/generically.haddock
haddock-html:         /usr/share/doc/haskell-generically/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-generically-0.1.1-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generically.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 generically
version:              0.1.1
visibility:           public
id:                   generically-0.1.1-JH4xBZSAJYOGZldlXfjkV1
key:                  generically-0.1.1-JH4xBZSAJYOGZldlXfjkV1
license:              BSD-3-Clause
copyright:            2022 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus
synopsis:             Generically newtype to use with DerivingVia
description:
    This is a compatibility package as @Generically@ and @Generically1@ newtypes
    are available since @base-4.17@ in '\''GHC.Generics'\''.

category:             Generics
abi:                  59af0c1280fbc5aed925996088decabe
exposed:              True
exposed-modules:      GHC.Generics.Generically
import-dirs:          /usr/lib/ghc-9.4.8/site-local/generically-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/generically-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/generically-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-generically
hs-libraries:         HSgenerically-0.1.1-JH4xBZSAJYOGZldlXfjkV1
depends:
    base-4.17.2.1 base-orphans-0.9.1-F3e4kqYU4KQ1QerC1pFV7l

haddock-interfaces:   /usr/share/doc/haskell-generically/html/generically.haddock
haddock-html:         /usr/share/doc/haskell-generically/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
